@@ -23,6 +23,8 @@ class Partner:
         birthdate_date,
         cooperator_register_number,
         cooperator_end_date,
+        coop_agreement_code,
+        sponsor_id,
         **kwargs
     ):
         self.id = id
@@ -39,6 +41,8 @@ class Partner:
         self.birthdate_date = birthdate_date
         self.cooperator_register_number = cooperator_register_number
         self.cooperator_end_date = cooperator_end_date
+        self.sponsor_id = sponsor_id
+        self.coop_agreement_code = coop_agreement_code
 
     @classmethod
     def get(cls, ref):
