@@ -59,10 +59,15 @@ class SubscriptionRequestFromPartnerForm:
         self.partner_data = partner_data
 
     def to_dict(self):
+        name = self._get_name()
         return {
             "type": self._type(),
-            "name": self.partner_data.get("name"),
+            "name": name,
+            "firstname": self.partner_data.get("name"),
+            "lastname": " ".join(
+                [self.partner_data.get("surname"), self.partner_data.get("lastname")]),
             "email": self.partner_data.get("email"),
+            "phone": self.partner_data.get("phone"),
             "address": {
                 "street": self.partner_data.get("street"),
                 "zip_code": self.partner_data.get("zip"),
@@ -77,18 +82,29 @@ class SubscriptionRequestFromPartnerForm:
             "nationality": self.partner_data.get("nationality"),
             "discovery_channel_id": int(self.partner_data.get("discovery_channel")),
 
-            # TODO: Add to the Odoo API/Model
             "sponsor_vat": self.partner_data.get("partner_number"),
-            "surname": self.partner_data.get("surname"),
+            "birthdate": self.partner_data.get("birth_date").strftime("%Y-%m-%d"),
+            "gender": self.partner_data.get("sex"),
             "is_company": self._is_company(),
-            # "birthdate": self.partner_data.get("birth_date").strftime("%m-%d-%Y"),
+            "company_name": self.partner_data.get("tradename"),
 
-            # TODO: Lastname, Tradename, Sex, Discovery Channel, Phone???
+            # TODO: Lastname, Tradename, Phone???
             "voluntary_contribution": int(self.partner_data.get(
                 "contribute_somconnexio_option"
             )),
         }
 
+    def _get_name(self):
+        if self.partner_data.get("party_type") == "organization":
+            return self.partner_data.get("name")
+        else:
+            return " ".join(
+                [
+                    self.partner_data.get("name"),
+                    self.partner_data.get("surname"),
+                    self.partner_data.get("lastname")
+                ])
+
     def _is_company(self):
         if self.partner_data.get("party_type") == "organization":
             return True
